@@ -1662,4 +1662,619 @@ class charging_status(msg):
     def __init__(self):
         super().__init__()
         self.data = self.data_class()  # 消息体
-        self.task_id = ''  # string型
\ No newline at end of file
+        self.task_id = ''  # string型
+    
+class get_radio(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+            
+            }
+    }
+    """
+    topic = "/get_radio"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+class get_radio_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+            "radio": 0.1 (0.1至1.0)
+            error_code : ""  # int型
+            error_msg : ""  # string型
+            result : ""  # int型
+            }
+    }
+    """
+    topic = "/get_radio_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.radio = ""
+            self.error_code = ""  # int型
+            self.error_msg = ""  # string型
+            self.result = ""  # int型
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+        
+class set_radio(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+            "radio": 0.1 (0.1至1.0)
+            }
+    }
+    """
+    topic = "/set_radio"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.radio = ""
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+    
+class set_radio_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+            error_code : ""  # int型
+            error_msg : ""  # string型
+            result : ""  # int型
+            }
+    }
+    """
+    topic = "/set_radio_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ""  # int型
+            self.error_msg = ""  # string型
+            self.result = ""  # int型
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+# 循迹列表请求
+class track_list(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "data": true
+            }
+    }
+    """
+    topic = "/track_list"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.data = True
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+# 循迹任务列表返回
+class track_list_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "data":[
+                {
+                    "index":0,
+                    "x":"0.1",
+                    "y":"0.1",
+                    "theta":"1.6",
+                    "createtime":'1654655744',
+                    "preset":1,
+                    "type": "digital",
+                    "type_text": "数字表识别"
+                }
+            ]
+        }
+    }
+    """
+    topic = "/track_list_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.data = []
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+# 循迹关键点添加
+class add_taskpoint(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "index":0 #第几个关键点
+            }
+    }
+    """
+    topic = "/add_taskpoint"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.index = '' #int型
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+# 循迹关键点添加返回
+class add_taskpoint_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/add_taskpoint_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 循迹关键点删除
+class delete_taskpoint(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "index":0 #第几个关键点
+            }
+    }
+    """
+    topic = "/delete_taskpoint"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.index = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 循迹关键点删除返回
+class delete_taskpoint_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/delete_taskpoint_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 客户端添加循迹关键点
+class add_taskpoint_client(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "index":0,
+                "x":"0.1",
+                "y":"0.1",
+                "theta":"1.6",
+                "createtime":'1654655744',
+                "preset":1,
+                "type": "digital",
+                "type_text": "数字表识别"
+            }
+    }
+    """
+    topic = "/add_taskpoint_client"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.index = ''
+            self.x = ''
+            self.y = ''
+            self.theta = ''
+            self.createtime = ''
+            self.preset = ''
+            self.type = ''
+            self.type_text = ''
+            self.cream = ''
+            self.cream_text = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+        
+# 客户端添加循迹关键点返回
+class add_taskpoint_client_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/add_taskpoint_client_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 客户端删除循迹关键点
+class delete_taskpoint_client(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "index":0
+            }
+    }
+    """
+    topic = "/delete_taskpoint_client"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.index = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 客户端删除循迹关键点返回
+class delete_taskpoint_client_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/delete_taskpoint_client_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 客户端修改循迹关键点
+class update_taskpoint_client(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "index":0,
+                "x":"0.1",
+                "y":"0.1",
+                "theta":"1.6",
+                "createtime":'1654655744',
+                "preset":1,
+                "type": "digital",
+                "type_text": "数字表识别"
+            }
+    }
+    """
+    topic = "/update_taskpoint_client"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.index = ''
+            self.x = ''
+            self.y = ''
+            self.theta = ''
+            self.createtime = ''
+            self.preset = ''
+            self.type = ''
+            self.type_text = ''
+            self.cream = ''
+            self.cream_text = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 客户端修改循迹关键点返回
+class update_taskpoint_client_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/update_taskpoint_client_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 到达关键点
+class reach_taskpoint(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "index":0,
+            }
+    }
+    """
+    topic = "/reach_taskpoint"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.index = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 到达关键点返回
+class reach_taskpoint_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/reach_taskpoint_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 录制循迹
+class track_record(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "action":0, 1:开始录制 0:结束录制
+            }
+    }
+    """
+    topic = "/track_record"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.action = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 录制循迹返回
+class track_record_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/track_record_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 开始循迹
+class start_track(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "action":0, 1:开始循迹 0:结束循迹
+            }
+    }
+    """
+    topic = "/start_track"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.action = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 开始循迹返回
+class start_track_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/start_track_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 获取循迹状态
+class get_track(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "action":1, 1 默认1
+            }
+    }
+    """
+    topic = "/get_track"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.action = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 获取循迹状态返回
+class get_track_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1 # 1:循迹中 0:未循迹
+        }
+    }
+    """
+    topic = "/get_track_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 获取循迹录制状态
+class get_track_record(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg": {
+                "action":1, 1 默认1
+            }
+    }
+    """
+    topic = "/get_track_record"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.action = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
+
+# 获取循迹录制状态返回
+class get_track_record_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1 # 1:录制中 0:未录制
+        }
+    }
+    """
+    topic = "/get_track_record_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ''
+            self.error_msg = ''
+            self.result = ''
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()
